@@ -1,4 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 
-from test_stock_product_location import *
+from .test_stock_product_location import suite
+
+__all__ = ['suite']
